@@ -27,6 +27,7 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import print_function
 import os
 from unilint.cpp_source_plugin import AbstractCppPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
@@ -79,7 +80,7 @@ class CpplintPlugin(AbstractCppPlugin):
                                       ignore_returncodes=[1])
 
         if options.raw:
-            print output
+            print(output)
             return None
         else:
             return self.parse(output)
