@@ -27,6 +27,7 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import print_function
 import os
 from unilint.python_source_plugin import AbstractPythonPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
@@ -83,7 +84,7 @@ class Pep8Plugin(AbstractPythonPlugin):
                                       us_env=True)
 
         if options.raw:
-            print output
+            print(output)
             return None
         else:
             basepath = os.path.dirname(path)
