@@ -27,6 +27,7 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import print_function
 import os
 from unilint.python_source_plugin import AbstractPythonPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
@@ -79,8 +80,8 @@ class PycheckerPlugin(AbstractPythonPlugin):
                                       ignore_returncodes=[1, 2, 123])
 
         if options.raw:
-            print path
-            print output
+            print(path)
+            print(output)
             return None
         else:
             return self.parse(output)
