@@ -27,6 +27,7 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import print_function
 from unilint.python_source_plugin import AbstractPythonPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
 from unilint.issue import Issue
@@ -69,7 +70,7 @@ class PyflakesPlugin(AbstractPythonPlugin):
                                       shell=True,
                                       us_env=True)
         if options.raw:
-            print output
+            print(output)
             return None
         else:
             return self.parse(output)
