@@ -27,6 +27,7 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import print_function
 import os
 from unilint.python_source_plugin import AbstractPythonPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
@@ -89,7 +90,7 @@ class PylintPlugin(AbstractPythonPlugin):
         output += '\n'
         basepath = os.path.dirname(path)
         if options.raw:
-            print output
+            print(output)
             return None
         return self.parse(output, basepath)
 
