@@ -28,7 +28,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import os
-
+import sys
 from unilint.unilint_main import register_formatter
 from unilint.custom_format import print_formatted
 
@@ -36,6 +36,7 @@ from unilint.custom_format import print_formatted
 
 
 def register_standard_formatters():
+
     def print_brief(unused_options, issue_list, basepath):
         if issue_list is None:
             return
@@ -49,7 +50,7 @@ def register_standard_formatters():
                                        str(issue.line_number_start or '').ljust(3),
                                        str(issue.line_position or '').ljust(3))
             location = location.ljust(20)
-            print("%s   %s" % (location, issue.message))
+            sys.stdout.write("%s   %s\n" % (location, issue.message))
 
     def print_full(unused_options, issue_list, basepath):
         print_formatted('[$C\t$S\t$T]$F:$L:$P:\t$M', issue_list, basepath)
